@@ -1,4 +1,4 @@
-#line 3782 "ifupdown.nw"
+#line 3823 "ifupdown.nw"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -9,7 +9,7 @@
 #include "archlinux.h"
 
 unsigned int mylinuxver() {
-	static int maj = -1, rev, min;
+	static int maj = -1, rev = 0, min = 0;
 
 	if (maj == -1) {
 		struct utsname u;
@@ -17,9 +17,13 @@ unsigned int mylinuxver() {
 		uname(&u);
 		maj = atoi(u.release);
 		pch = strchr(u.release, '.');
-		rev = atoi(pch+1);
-		pch = strchr(pch+1, '.');
-		min = atoi(pch+1);
+		if (pch) {
+			rev = atoi(pch+1);
+			pch = strchr(pch+1, '.');
+			if (pch) {
+				min = atoi(pch+1);
+			}
+		}
 	}
 
 	return mylinux(maj,rev,min);
